@@ -8,6 +8,10 @@
 # include <stdio.h>
 #endif
 
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
 #if SIZEOF_UNSIGNED_LONG_INT == 4
  typedef unsigned long word32;
 #elif SIZEOF_UNSIGNED_INT == 4
