@@ -39,8 +39,14 @@ int init_mcrypt_ofb( const int algorithm, void * key, int lenofkey, void *IV);
 # define TripleDES 2
 # define ThreeWAY 3
 # define GOST 4
+
+#ifdef MCRYPT2
+# define CRYPT 5
+#endif
+
 # define SAFER64 6
 # define SAFER128 7
 # define CAST128 8
 # define TEAN 9
 # define TWOFISH 10
+# define RC2 11
